Description:

this package is helpfull package for flutter app template in codecanyon so it give you the ability to get the languages

Installation:

Add the following dependency to your pubspec.yaml file:

dependencies:
  toplanguage: ^0.0.2